@@ -1,3 +1,4 @@
+from collections import OrderedDict
 from threading import Thread
 
 
@@ -52,7 +53,7 @@ def thread_task(task_list: list, result_type="list", error_ignore=False):
     if result_type == "list":
         return [i.get_result() for i in thread_list]
     else:
-        result = dict()
+        result = OrderedDict()
         for i, _thread in enumerate(thread_list):
             result.update(
                 {name_list[i]: {"func": _thread.func_name, "name": name_list[i], "data": _thread.get_result()}})
